﻿using System;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Input;
using Telerik.Windows.Controls;
using Telerik.Windows.Controls.GridView;
using System.Collections;

namespace Samples.GridView.CellContentVisibility
{
    public partial class VisibilityControl : UserControl
    {
        private GridViewRow parentRow;
        private bool isMouseOver;

        public Visibility ComputedVisibility
        {
            get { return (Visibility)GetValue(ComputedVisibilityProperty); }
            set { SetValue(ComputedVisibilityProperty, value); }
        }

        public static readonly DependencyProperty ComputedVisibilityProperty =
            DependencyProperty.Register("ComputedVisibility", typeof(Visibility), typeof(VisibilityControl), new PropertyMetadata(Visibility.Visible));

        public VisibilityControl()
        {
            InitializeComponent();

            // binding Button's Visibility property to ComputedVisibility
            Binding binding = new Binding("ComputedVisibility");
            binding.Mode = BindingMode.OneWay;
            binding.Source = this;

            this.ChildContent.SetBinding(Button.VisibilityProperty, binding);
        }

        // analyzes all conditions and determines the current ComputedVisibiliy value
        private void ComputeVisibility()
        {
            bool isSelected = this.parentRow.DataItem == this.parentRow.ParentGrid.SelectedItem;

            if (isSelected || isMouseOver)
                this.ComputedVisibility = Visibility.Visible;
            else
                this.ComputedVisibility = Visibility.Collapsed;
        }

        private void Button_Click(object sender, RoutedEventArgs e)
        {
            // execute action

            var senderElement = (FrameworkElement)sender;
            var parentRow = senderElement.ParentOfType<GridViewRow>();

            ((IList)parentRow.ParentGrid.ItemsSource).Remove(parentRow.DataItem);
        }

        private void UserControl_Loaded(object sender, RoutedEventArgs e)
        {
            this.parentRow = this.ParentOfType<GridViewRow>();

            this.parentRow.MouseEnter += new MouseEventHandler(parentRow_MouseEnter);
            this.parentRow.MouseLeave += new MouseEventHandler(parentRow_MouseLeave);
            this.parentRow.ParentGrid.SelectionChanged += new EventHandler<SelectionChangeEventArgs>(ParentGrid_SelectionChanged);

            this.ComputeVisibility();
        }

        void ParentGrid_SelectionChanged(object sender, SelectionChangeEventArgs e)
        {
            ComputeVisibility();
        }

        void parentRow_MouseLeave(object sender, MouseEventArgs e)
        {
            this.isMouseOver = false;
            this.ComputeVisibility();
        }

        void parentRow_MouseEnter(object sender, MouseEventArgs e)
        {
            this.isMouseOver = true;
            this.ComputeVisibility();
        }
    }
}
